[gnome-shell] Revert "Give user 48ms to read each character of a PAM message, earlier it was 16ms"



commit 23a9fb0314428c9e805f3434437d3d3a59a06bbe
Author: Adel Gadllah <adel gadllah gmail com>
Date:   Fri Mar 27 14:33:52 2015 +0100

    Revert "Give user 48ms to read each character of a PAM message, earlier it was 16ms"
    
    Seriously there has to be a better way to deal with this then slowing down
    login for messages that hardly anyone cares about.
    
    https://bugzilla.gnome.org/show_bug.cgi?id=720885
    
    This reverts commit 88973857146f91acd3b633234afa2c2bb358392a.

 js/gdm/util.js |    4 ++--
 1 files changed, 2 insertions(+), 2 deletions(-)
---
diff --git a/js/gdm/util.js b/js/gdm/util.js
index 2ff59cb..6286b84 100644
--- a/js/gdm/util.js
+++ b/js/gdm/util.js
@@ -35,8 +35,8 @@ const ALLOWED_FAILURES_KEY = 'allowed-failures';
 const LOGO_KEY = 'logo';
 const DISABLE_USER_LIST_KEY = 'disable-user-list';
 
-// Give user 48ms to read each character of a PAM message
-const USER_READ_TIME = 48
+// Give user 16ms to read each character of a PAM message
+const USER_READ_TIME = 16
 
 const MessageType = {
     NONE: 0,


[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]